struct Common {
matcher: Mutex<Matcher>,
seq_handle: Option<SeqHandle>,
times: Times,
}Expand description
Holds the stuff that is independent of the output type
Fields
matcher: Mutex<Matcher>seq_handle: Option<SeqHandle>times: TimesImplementations
Sourceimpl Common
impl Common
fn call<F: Fn() -> String>(&self, desc: F)
fn in_sequence(&mut self, __mockall_seq: &mut Sequence) -> &mut Self
fn is_done(&self) -> bool
fn matches<'a>( &self, domain_hint: &Option<&'a str>, return_url: &Option<&'a str>, user_identifier: &Option<&'a str>, sso_token: &Option<&'a str>, ) -> bool
fn satisfy_sequence(&self)
fn called_sequence(&self)
fn is_history_sequence(&self) -> bool
Sourcefn times<MockallR>(&mut self, __mockall_r: MockallR)where
MockallR: Into<TimesRange>,
fn times<MockallR>(&mut self, __mockall_r: MockallR)where
MockallR: Into<TimesRange>,
Expect this expectation to be called any number of times contained with the given range.
fn with<MockallMatcher0: for<'a> Predicate<Option<&'a str>> + Send + 'static, MockallMatcher1: for<'a> Predicate<Option<&'a str>> + Send + 'static, MockallMatcher2: for<'a> Predicate<Option<&'a str>> + Send + 'static, MockallMatcher3: for<'a> Predicate<Option<&'a str>> + Send + 'static>( &mut self, domain_hint: MockallMatcher0, return_url: MockallMatcher1, user_identifier: MockallMatcher2, sso_token: MockallMatcher3, )
fn withf<MockallF>(&mut self, __mockall_f: MockallF)
fn withf_st<MockallF>(&mut self, __mockall_f: MockallF)
fn verify_sequence<F: Fn() -> String>(&self, desc: F)